mailr9158 - /branches/frame_order/generic_fns/pymol.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on June 25, 2009 - 16:36:
Author: bugman
Date: Thu Jun 25 16:36:00 2009
New Revision: 9158

URL: http://svn.gna.org/viewcvs/relax?rev=9158&view=rev
Log:
cone_pdb() now handles the AXE residue.


Modified:
    branches/frame_order/generic_fns/pymol.py

Modified: branches/frame_order/generic_fns/pymol.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/frame_order/generic_fns/pymol.py?rev=9158&r1=9157&r2=9158&view=diff
==============================================================================
--- branches/frame_order/generic_fns/pymol.py (original)
+++ branches/frame_order/generic_fns/pymol.py Thu Jun 25 16:36:00 2009
@@ -225,8 +225,8 @@
     # Average CoM-pivot point vector.
     #################################
 
-    # Select the AVE residue.
-    pymol.pipe_write("select resn AVE")
+    # Select the AVE and AXE residues.
+    pymol.pipe_write("select resn AVE,AXE")
 
     # Show the vector as a stick.
     pymol.pipe_write("show stick, 'sele'")
@@ -235,7 +235,7 @@
     pymol.pipe_write("color cyan, 'sele'")
 
     # Select the atom used for labelling.
-    pymol.pipe_write("select (resn AVE and symbol N)")
+    pymol.pipe_write("select (resn AVE,AXE and symbol N)")
 
     # Hide the atom.
     pymol.pipe_write("hide ('sele')")




Related Messages


Powered by MHonArc, Updated Thu Jun 25 16:40:03 2009